@@ -25,8 +25,7 @@
 #include <termios.h>
 
 QUnixTerminalImpl::QUnixTerminalImpl(QWidget *p)
-    : QTerminal(p),
-      _parent (p)
+    : QTerminal(p)
 {
     initialize();
 }
@@ -51,14 +50,14 @@ void QUnixTerminalImpl::initialize()
     m_terminalView->filterChain ()->addFilter (file_filter);
 
     connect (file_filter, SIGNAL (request_edit_mfile_signal (const QString&, int)),
-             _parent, SLOT (edit_mfile (const QString&, int)));
-    connect (file_filter, SIGNAL (request_open_file_signal (const QString&, int)),
-             _parent, SLOT (open_file (const QString&, int)));
+             this, SIGNAL (request_edit_mfile_signal (const QString&, int)));
+    connect (file_filter, SIGNAL (request_open_file_signal (const QString&, const QString&,int)),
+             this, SIGNAL (request_open_file_signal (const QString&, const QString&,int)));
 
     connect(m_terminalView, SIGNAL(customContextMenuRequested(QPoint)),
             this, SLOT(handleCustomContextMenuRequested(QPoint)));
 
-    connect (m_terminalView, SIGNAL (interrupt_signal (void)),
+    connect (m_terminalView, SIGNAL (interrupt_signal ()),
              this, SLOT (terminal_interrupt ()));
 
 #ifdef Q_OS_MAC
@@ -107,8 +106,12 @@ QUnixTerminalImpl::get_hotspot_actions (const QPoint& at)
 
 void QUnixTerminalImpl::connectToPty()
 {
-    // Store the file descriptor associated with the STDERR stream onto
-    // another temporary file descriptor for reconnect in the destructor.
+    // Store the file descriptor associated with the STDIN, STDOUT, and
+    // STDERR streams onto another temporary file descriptor for
+    // reconnect in the destructor.
+
+    fdstdin = dup (STDIN_FILENO);
+    fdstdout = dup (STDOUT_FILENO);
     fdstderr = dup (STDERR_FILENO);
 
     int fds = m_kpty->slaveFd();
@@ -136,10 +139,14 @@ QUnixTerminalImpl::~QUnixTerminalImpl()
     delete m_kpty;
     delete m_terminalView;
 
-    // Restore stderr so that any errors at exit might appear somewhere.
+    // Restore STDIN, STDOUT, and STDERR so that I/O at exit will work
+    // as expected.
+
+    dup2 (fdstdin, STDIN_FILENO);
+    dup2 (fdstdout, STDOUT_FILENO);
     dup2 (fdstderr, STDERR_FILENO);
 
-    emit destroyed();
+    Q_EMIT destroyed();
 }
 
 void QUnixTerminalImpl::setTerminalFont(const QFont &font)
