@@ -1,24 +1,27 @@
-/*
-
-Copyright (C) 2000-2019 John W. Eaton
-
-This file is part of Octave.
-
-Octave is free software: you can redistribute it and/or modify it
-under the terms of the GNU General Public License as published by
-the Free Software Foundation, either version 3 of the License, or
-(at your option) any later version.
-
-Octave is distributed in the hope that it will be useful, but
-WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with Octave; see the file COPYING.  If not, see
-<https://www.gnu.org/licenses/>.
-
-*/
+////////////////////////////////////////////////////////////////////////
+//
+// Copyright (C) 2000-2025 The Octave Project Developers
+//
+// See the file COPYRIGHT.md in the top-level directory of this
+// distribution or <https://octave.org/copyright/>.
+//
+// This file is part of Octave.
+//
+// Octave is free software: you can redistribute it and/or modify it
+// under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// Octave is distributed in the hope that it will be useful, but
+// WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with Octave; see the file COPYING.  If not, see
+// <https://www.gnu.org/licenses/>.
+//
+////////////////////////////////////////////////////////////////////////
 
 #if defined (HAVE_CONFIG_H)
 #  include "config.h"
@@ -30,6 +33,8 @@ along with Octave; see the file COPYING.  If not, see
 
 #include "c-file-ptr-stream.h"
 
+OCTAVE_BEGIN_NAMESPACE(octave)
+
 #if ! defined (SEEK_SET)
 #  define SEEK_SET 0
 #endif
@@ -42,7 +47,7 @@ along with Octave; see the file COPYING.  If not, see
 #  define SEEK_END 2
 #endif
 
-c_file_ptr_buf::~c_file_ptr_buf (void)
+c_file_ptr_buf::~c_file_ptr_buf ()
 {
   buf_close ();
 }
@@ -52,8 +57,8 @@ c_file_ptr_buf::~c_file_ptr_buf (void)
 c_file_ptr_buf::int_type
 c_file_ptr_buf::overflow (int_type c)
 {
-  if (f)
-    return (c != traits_type::eof ()) ? std::fputc (c, f) : flush ();
+  if (m_f)
+    return (c != traits_type::eof ()) ? std::fputc (c, m_f) : flush ();
   else
     return traits_type::not_eof (c);
 }
@@ -61,12 +66,12 @@ c_file_ptr_buf::overflow (int_type c)
 c_file_ptr_buf::int_type
 c_file_ptr_buf::underflow_common (bool bump)
 {
-  if (f)
+  if (m_f)
     {
-      int_type c = std::fgetc (f);
+      int_type c = std::fgetc (m_f);
 
       if (! bump && c != traits_type::eof ())
-        ungetc (c, f);
+        ungetc (c, m_f);
 
       return c;
     }
@@ -77,15 +82,15 @@ c_file_ptr_buf::underflow_common (bool bump)
 c_file_ptr_buf::int_type
 c_file_ptr_buf::pbackfail (int_type c)
 {
-  return ((c != traits_type::eof () && f)
-          ? ungetc (c, f) : traits_type::not_eof (c));
+  return ((c != traits_type::eof () && m_f)
+          ? ungetc (c, m_f) : traits_type::not_eof (c));
 }
 
 std::streamsize
 c_file_ptr_buf::xsputn (const char *s, std::streamsize n)
 {
-  if (f)
-    return std::fwrite (s, 1, n, f);
+  if (m_f)
+    return std::fwrite (s, 1, n, m_f);
   else
     return 0;
 }
@@ -93,8 +98,8 @@ c_file_ptr_buf::xsputn (const char *s, std::streamsize n)
 std::streamsize
 c_file_ptr_buf::xsgetn (char *s, std::streamsize n)
 {
-  if (f)
-    return std::fread (s, 1, n, f);
+  if (m_f)
+    return std::fread (s, 1, n, m_f);
   else
     return 0;
 }
@@ -113,11 +118,11 @@ c_file_ptr_buf::seekoff (std::streamoff offset,
                          std::ios::seekdir dir,
                          std::ios::openmode)
 {
-  if (f)
+  if (m_f)
     {
-      octave_fseeko_wrapper (f, offset, seekdir_to_whence (dir));
+      octave_fseeko_wrapper (m_f, offset, seekdir_to_whence (dir));
 
-      return octave_ftello_wrapper (f);
+      return octave_ftello_wrapper (m_f);
     }
   else
     return 0;
@@ -126,18 +131,18 @@ c_file_ptr_buf::seekoff (std::streamoff offset,
 std::streampos
 c_file_ptr_buf::seekpos (std::streampos offset, std::ios::openmode)
 {
-  if (f)
+  if (m_f)
     {
-      octave_fseeko_wrapper (f, offset, SEEK_SET);
+      octave_fseeko_wrapper (m_f, offset, SEEK_SET);
 
-      return octave_ftello_wrapper (f);
+      return octave_ftello_wrapper (m_f);
     }
   else
     return 0;
 }
 
 int
-c_file_ptr_buf::sync (void)
+c_file_ptr_buf::sync ()
 {
   flush ();
 
@@ -145,22 +150,22 @@ c_file_ptr_buf::sync (void)
 }
 
 int
-c_file_ptr_buf::flush (void)
+c_file_ptr_buf::flush ()
 {
-  return f ? std::fflush (f) : traits_type::eof ();
+  return m_f ? std::fflush (m_f) : traits_type::eof ();
 }
 
 int
-c_file_ptr_buf::buf_close (void)
+c_file_ptr_buf::buf_close ()
 {
   int retval = -1;
 
   flush ();
 
-  if (f)
+  if (m_f)
     {
-      retval = cf (f);
-      f = nullptr;
+      retval = m_cf (m_f);
+      m_f = nullptr;
     }
 
   return retval;
@@ -169,24 +174,24 @@ c_file_ptr_buf::buf_close (void)
 int
 c_file_ptr_buf::seek (off_t offset, int origin)
 {
-  return f ? octave_fseeko_wrapper (f, offset, origin) : -1;
+  return m_f ? octave_fseeko_wrapper (m_f, offset, origin) : -1;
 }
 
 off_t
-c_file_ptr_buf::tell (void)
+c_file_ptr_buf::tell ()
 {
-  return f ? octave_ftello_wrapper (f) : -1;
+  return m_f ? octave_ftello_wrapper (m_f) : -1;
 }
 
 int
-c_file_ptr_buf::file_close (FILE *f)
+c_file_ptr_buf::file_close (FILE *m_f)
 {
-  return std::fclose (f);
+  return std::fclose (m_f);
 }
 
 #if defined (HAVE_ZLIB)
 
-c_zfile_ptr_buf::~c_zfile_ptr_buf (void)
+c_zfile_ptr_buf::~c_zfile_ptr_buf ()
 {
   buf_close ();
 }
@@ -196,8 +201,8 @@ c_zfile_ptr_buf::~c_zfile_ptr_buf (void)
 c_zfile_ptr_buf::int_type
 c_zfile_ptr_buf::overflow (int_type c)
 {
-  if (f)
-    return (c != traits_type::eof ()) ? gzputc (f, c) : flush ();
+  if (m_f)
+    return (c != traits_type::eof ()) ? gzputc (m_f, c) : flush ();
   else
     return traits_type::not_eof (c);
 }
@@ -205,12 +210,12 @@ c_zfile_ptr_buf::overflow (int_type c)
 c_zfile_ptr_buf::int_type
 c_zfile_ptr_buf::underflow_common (bool bump)
 {
-  if (f)
+  if (m_f)
     {
-      int_type c = gzgetc (f);
+      int_type c = gzgetc (m_f);
 
       if (! bump && c != traits_type::eof ())
-        gzungetc (c, f);
+        gzungetc (c, m_f);
 
       return c;
     }
@@ -221,15 +226,15 @@ c_zfile_ptr_buf::underflow_common (bool bump)
 c_zfile_ptr_buf::int_type
 c_zfile_ptr_buf::pbackfail (int_type c)
 {
-  return ((c != traits_type::eof () && f)
-          ? gzungetc (c, f) : traits_type::not_eof (c));
+  return ((c != traits_type::eof () && m_f)
+          ? gzungetc (c, m_f) : traits_type::not_eof (c));
 }
 
 std::streamsize
 c_zfile_ptr_buf::xsputn (const char *s, std::streamsize n)
 {
-  if (f)
-    return gzwrite (f, s, n);
+  if (m_f)
+    return gzwrite (m_f, s, n);
   else
     return 0;
 }
@@ -237,8 +242,8 @@ c_zfile_ptr_buf::xsputn (const char *s, std::streamsize n)
 std::streamsize
 c_zfile_ptr_buf::xsgetn (char *s, std::streamsize n)
 {
-  if (f)
-    return gzread (f, s, n);
+  if (m_f)
+    return gzread (m_f, s, n);
   else
     return 0;
 }
@@ -248,39 +253,17 @@ c_zfile_ptr_buf::seekoff (std::streamoff /* offset */,
                           std::ios::seekdir /* dir */,
                           std::ios::openmode)
 {
-  // FIXME
-#if 0
-  if (f)
-    {
-      gzseek (f, offset, seekdir_to_whence (dir));
-
-      return gztell (f);
-    }
-  else
-    return 0;
-#endif
   return -1;
 }
 
 std::streampos
 c_zfile_ptr_buf::seekpos (std::streampos /* offset */, std::ios::openmode)
 {
-  // FIXME
-#if 0
-  if (f)
-    {
-      gzseek (f, offset, SEEK_SET);
-
-      return gztell (f);
-    }
-  else
-    return 0;
-#endif
   return -1;
 }
 
 int
-c_zfile_ptr_buf::sync (void)
+c_zfile_ptr_buf::sync ()
 {
   flush ();
 
@@ -288,29 +271,31 @@ c_zfile_ptr_buf::sync (void)
 }
 
 int
-c_zfile_ptr_buf::flush (void)
+c_zfile_ptr_buf::flush ()
 {
   // FIXME: do we need something more complex here, passing
   // something other than 0 for the second argument to gzflush and
   // checking the return value, etc.?
 
-  return f ? gzflush (f, 0) : traits_type::eof ();
+  return m_f ? gzflush (m_f, 0) : traits_type::eof ();
 }
 
 int
-c_zfile_ptr_buf::buf_close (void)
+c_zfile_ptr_buf::buf_close ()
 {
   int retval = -1;
 
   flush ();
 
-  if (f)
+  if (m_f)
     {
-      retval = cf (f);
-      f = nullptr;
+      retval = m_cf (m_f);
+      m_f = nullptr;
     }
 
   return retval;
 }
 
 #endif
+
+OCTAVE_END_NAMESPACE(octave)
