@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////
 //
-// Copyright (C) 1993-2023 The Octave Project Developers
+// Copyright (C) 1993-2025 The Octave Project Developers
 //
 // See the file COPYRIGHT.md in the top-level directory of this
 // distribution or <https://octave.org/copyright/>.
@@ -32,7 +32,6 @@
 #include <cstdio>
 #include <cstdlib>
 #include <cstring>
-#include <cassert>
 
 #include <algorithm>
 #include <iostream>
@@ -70,7 +69,6 @@
 #include "ov-fcn-handle.h"
 #include "ov-usr-fcn.h"
 #include "pager.h"
-#include "parse.h"
 #include "pt-eval.h"
 #include "pt-stmt.h"
 #include "sighandlers.h"
@@ -259,16 +257,16 @@ generate_possible_completions (const std::string& text, std::string& prefix,
 }
 
 static bool
-is_completing_dirfns (void)
+is_completing_dirfns ()
 {
   static std::string dirfns_commands[] = {"cd", "isfile", "isfolder", "ls"};
-  static const std::size_t dirfns_commands_length = 4;
+  static const std::size_t DIRFNS_COMMANDS_LENGTH = 4;
 
   bool retval = false;
 
   std::string line = command_editor::get_line_buffer ();
 
-  for (std::size_t i = 0; i < dirfns_commands_length; i++)
+  for (std::size_t i = 0; i < DIRFNS_COMMANDS_LENGTH; i++)
     {
       int index = line.find (dirfns_commands[i] + ' ');
 
@@ -386,7 +384,8 @@ generate_completion (const std::string& text, int state)
   return retval;
 }
 
-static int internal_input_event_hook_fcn (void)
+static int
+internal_input_event_hook_fcn ()
 {
   octave_quit ();
 
@@ -409,7 +408,8 @@ input_system::input_system (interpreter& interp)
     m_initialized (false)
 { }
 
-void input_system::initialize (bool line_editing)
+void
+input_system::initialize (bool line_editing)
 {
   if (m_initialized)
     return;
@@ -489,7 +489,7 @@ input_system::mfile_encoding (const octave_value_list& args, int nargout)
 
   octave_value retval
     = set_internal_variable (m_mfile_encoding, args, nargout,
-                             "__mfile_encoding__");
+                             "mfile_encoding");
 
   // Additional validation if the encoding has changed.
 
@@ -516,10 +516,10 @@ input_system::mfile_encoding (const octave_value_list& args, int nargout)
             {
               m_mfile_encoding = saved_encoding;
               if (errno == EINVAL)
-                error ("__mfile_encoding__: conversion from encoding '%s' "
+                error ("mfile_encoding: conversion from encoding '%s' "
                        "not supported", encoding.c_str ());
               else
-                error ("__mfile_encoding__: error %d opening encoding '%s'",
+                error ("mfile_encoding: error %d opening encoding '%s'",
                        errno, encoding.c_str ());
             }
           else
@@ -529,14 +529,14 @@ input_system::mfile_encoding (const octave_value_list& args, int nargout)
     }
 
   // Synchronize the related gui preference for editor encoding
-  feval ("__event_manager_gui_preference__",
-         ovl ("editor/default_encoding", m_mfile_encoding));
+  F__event_manager_gui_preference__ (m_interpreter, ovl ("editor/default_encoding", m_mfile_encoding));
 
   return retval;
 }
 
 // Get part of the directory that would be added to the load path
-static std::string load_path_dir (const std::string& dir)
+static std::string
+load_path_dir (const std::string& dir)
 {
   std::string lp_dir = dir;
 
@@ -571,7 +571,8 @@ static std::string load_path_dir (const std::string& dir)
   return lp_dir;
 }
 
-std::string input_system::dir_encoding (const std::string& dir)
+std::string
+input_system::dir_encoding (const std::string& dir)
 {
   std::string enc = m_mfile_encoding;
   // use canonicalized path as key
@@ -584,8 +585,9 @@ std::string input_system::dir_encoding (const std::string& dir)
   return enc;
 }
 
-void input_system::set_dir_encoding (const std::string& dir,
-                                     std::string& enc)
+void
+input_system::set_dir_encoding (const std::string& dir,
+                                std::string& enc)
 {
   // use lower case
   std::transform (enc.begin (), enc.end (), enc.begin (), ::tolower);
@@ -631,7 +633,8 @@ input_system::auto_repeat_debug_command (const octave_value_list& args,
                                 "auto_repeat_debug_command");
 }
 
-bool input_system::yes_or_no (const std::string& prompt)
+bool
+input_system::yes_or_no (const std::string& prompt)
 {
   std::string prompt_string = prompt + "(yes or no) ";
 
@@ -650,7 +653,8 @@ bool input_system::yes_or_no (const std::string& prompt)
     }
 }
 
-std::string input_system::interactive_input (const std::string& s, bool& eof)
+std::string
+input_system::interactive_input (const std::string& s, bool& eof)
 {
   Vlast_prompt_time.stamp ();
 
@@ -747,17 +751,20 @@ input_system::get_user_input (const octave_value_list& args, int nargout)
   return retval;
 }
 
-bool input_system::have_input_event_hooks (void) const
+bool
+input_system::have_input_event_hooks () const
 {
   return ! m_input_event_hook_functions.empty ();
 }
 
-void input_system::add_input_event_hook (const hook_function& hook_fcn)
+void
+input_system::add_input_event_hook (const hook_function& hook_fcn)
 {
   m_input_event_hook_functions.insert (hook_fcn.id (), hook_fcn);
 }
 
-bool input_system::remove_input_event_hook (const std::string& hook_fcn_id)
+bool
+input_system::remove_input_event_hook (const std::string& hook_fcn_id)
 {
   hook_function_list::iterator p
     = m_input_event_hook_functions.find (hook_fcn_id);
@@ -769,12 +776,14 @@ bool input_system::remove_input_event_hook (const std::string& hook_fcn_id)
   return true;
 }
 
-void input_system::clear_input_event_hooks (void)
+void
+input_system::clear_input_event_hooks ()
 {
   m_input_event_hook_functions.clear ();
 }
 
-void input_system::run_input_event_hooks (void)
+void
+input_system::run_input_event_hooks ()
 {
   m_input_event_hook_functions.run ();
 }
@@ -794,7 +803,8 @@ input_system::gnu_readline (const std::string& s, bool& eof) const
   return retval;
 }
 
-std::string base_reader::octave_gets (const std::string& prompt, bool& eof)
+std::string
+base_reader::octave_gets (const std::string& prompt, bool& eof)
 {
   octave_quit ();
 
@@ -878,8 +888,7 @@ std::string base_reader::octave_gets (const std::string& prompt, bool& eof)
   return retval;
 }
 
-class
-terminal_reader : public base_reader
+class terminal_reader : public base_reader
 {
 public:
 
@@ -889,9 +898,9 @@ public:
 
   std::string get_input (const std::string& prompt, bool& eof);
 
-  std::string input_source (void) const { return s_in_src; }
+  std::string input_source () const { return s_in_src; }
 
-  bool input_from_terminal (void) const { return true; }
+  bool input_from_terminal () const { return true; }
 
 private:
 
@@ -901,8 +910,7 @@ private:
   static const std::string s_in_src;
 };
 
-class
-file_reader : public base_reader
+class file_reader : public base_reader
 {
 public:
 
@@ -918,9 +926,9 @@ public:
 
   std::string get_input (const std::string& prompt, bool& eof);
 
-  std::string input_source (void) const { return s_in_src; }
+  std::string input_source () const { return s_in_src; }
 
-  bool input_from_file (void) const { return true; }
+  bool input_from_file () const { return true; }
 
 private:
 
@@ -931,8 +939,7 @@ private:
   static const std::string s_in_src;
 };
 
-class
-eval_string_reader : public base_reader
+class eval_string_reader : public base_reader
 {
 public:
 
@@ -942,9 +949,9 @@ public:
 
   std::string get_input (const std::string& prompt, bool& eof);
 
-  std::string input_source (void) const { return s_in_src; }
+  std::string input_source () const { return s_in_src; }
 
-  bool input_from_eval_string (void) const { return true; }
+  bool input_from_eval_string () const { return true; }
 
 private:
 
@@ -1099,7 +1106,7 @@ file_reader::get_input (const std::string& /*prompt*/, bool& eof)
                "converting from codepage '%s' to UTF-8: %s",
                encoding.c_str (), std::strerror (errno));
 
-      unwind_action free_utf8_str ([=] () { ::free (utf8_str); });
+      unwind_action free_utf8_str ([utf8_str] () { ::free (utf8_str); });
 
       src_str = std::string (reinterpret_cast<char *> (utf8_str), length);
     }
@@ -1444,8 +1451,7 @@ for input.
   if (nargin < 1 || nargin > 2)
     print_usage ();
 
-  std::string hook_fcn_id = args(
-                              0).xstring_value ("remove_input_event_hook: argument not valid as a hook function name or id");
+  std::string hook_fcn_id = args(0).xstring_value ("remove_input_event_hook: argument not valid as a hook function name or id");
 
   bool warn = (nargin < 2);
 
@@ -1497,9 +1503,7 @@ The original variable value is restored when exiting the function.
 @seealso{PS2, PS4}
 @end deftypefn */)
 {
-  input_system& input_sys = interp.get_input_system ();
-
-  return input_sys.PS1 (args, nargout);
+  return interp.PS1 (args, nargout);
 }
 
 DEFMETHOD (PS2, interp, args, nargout,
@@ -1521,9 +1525,7 @@ The original variable value is restored when exiting the function.
 @seealso{PS1, PS4}
 @end deftypefn */)
 {
-  input_system& input_sys = interp.get_input_system ();
-
-  return input_sys.PS2 (args, nargout);
+  return interp.PS2 (args, nargout);
 }
 
 DEFMETHOD (completion_append_char, interp, args, nargout,
@@ -1577,14 +1579,32 @@ Undocumented internal function.
   return input_sys.gud_mode (args, nargout);
 }
 
-DEFMETHOD (__mfile_encoding__, interp, args, nargout,
+DEFMETHOD (mfile_encoding, interp, args, nargout,
            doc: /* -*- texinfo -*-
-@deftypefn  {} {@var{current_encoding} =} __mfile_encoding__ ()
-@deftypefnx {} {} __mfile_encoding__ (@var{new_encoding})
-@deftypefnx {} {@var{old_encoding} =} __mfile_encoding__ (@var{new_encoding})
-Query or set the codepage that is used for reading m-files.
+@deftypefn  {} {@var{current_encoding} =} mfile_encoding ()
+@deftypefnx {} {} mfile_encoding (@var{new_encoding})
+@deftypefnx {} {@var{old_encoding} =} mfile_encoding (@var{new_encoding})
+Query or set the encoding that is used for reading m-files.
 
-The input and output are strings naming a particular codepage, e.g., "utf-8".
+The input and output are strings naming an encoding, e.g.,
+@nospell{@qcode{"utf-8"}}.
+
+This encoding is used by Octave's parser when reading m-files unless a
+different encoding was set for a specific directory containing m-files using
+the function @code{dir_encoding} or in a file @file{.oct-config} in that
+directory.
+
+The special value @qcode{"system"} selects the encoding that matches the system
+locale.
+
+If the m-file encoding is changed after the m-files have already been parsed,
+the files have to be parsed again for that change to take effect.  That can be
+triggered with the command @code{clear all}.
+
+Additionally, this encoding is used to load and save files with the built-in
+editor in Octave's GUI.
+
+@seealso{dir_encoding}
 @end deftypefn */)
 {
   input_system& input_sys = interp.get_input_system ();
@@ -1592,6 +1612,8 @@ The input and output are strings naming a particular codepage, e.g., "utf-8".
   return input_sys.mfile_encoding (args, nargout);
 }
 
+DEFALIAS (__mfile_encoding__, mfile_encoding);
+
 DEFMETHOD (dir_encoding, interp, args, nargout,
            doc: /* -*- texinfo -*-
 @deftypefn  {} {@var{current_encoding} =} dir_encoding (@var{dir})
@@ -1600,7 +1622,8 @@ DEFMETHOD (dir_encoding, interp, args, nargout,
 @deftypefnx {} {@var{old_encoding} =} dir_encoding (@var{dir}, @var{new_encoding})
 Query or set the @var{encoding} that is used for reading m-files in @var{dir}.
 
-The per-directory encoding overrides the (globally set) m-file encoding.
+The per-directory encoding overrides the (globally set) m-file encoding,
+@pxref{XREFmfile_encoding,,@code{mfile_encoding}}.
 
 The string @var{DIR} must match how the directory would appear in the load
 path.
@@ -1629,7 +1652,7 @@ If the file encoding is changed after the files have already been parsed, the
 files have to be parsed again for that change to take effect.  That can be done
 with the command @code{clear all}.
 
-@seealso{addpath, path}
+@seealso{addpath, path, mfile_encoding}
 @end deftypefn */)
 {
   int nargin = args.length ();
