@@ -1,4 +1,4 @@
-/* A Bison parser, made by GNU Bison 3.7.5.  */
+/* A Bison parser, made by GNU Bison 3.8.2.  */
 
 /* Bison implementation for Yacc-like parsers in C
 
@@ -16,7 +16,7 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
+   along with this program.  If not, see <https://www.gnu.org/licenses/>.  */
 
 /* As a special exception, you may create a larger work that contains
    part or all of the Bison parser skeleton and distribute that work
@@ -46,10 +46,10 @@
    USER NAME SPACE" below.  */
 
 /* Identify Bison output, and Bison version.  */
-#define YYBISON 30705
+#define YYBISON 30802
 
 /* Bison version string.  */
-#define YYBISON_VERSION "3.7.5"
+#define YYBISON_VERSION "3.8.2"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -58,7 +58,7 @@
 #define YYPURE 1
 
 /* Push parsers.  */
-#define YYPUSH 0
+#define YYPUSH 1
 
 /* Pull parsers.  */
 #define YYPULL 1
@@ -67,6 +67,12 @@
 #define YYSTYPE         OCTAVE_TEX_STYPE
 /* Substitute the variable and function names.  */
 #define yyparse         octave_tex_parse
+#define yypush_parse    octave_tex_push_parse
+#define yypull_parse    octave_tex_pull_parse
+#define yypstate_new    octave_tex_pstate_new
+#define yypstate_clear  octave_tex_pstate_clear
+#define yypstate_delete octave_tex_pstate_delete
+#define yypstate        octave_tex_pstate
 #define yylex           octave_tex_lex
 #define yyerror         octave_tex_error
 #define yydebug         octave_tex_debug
@@ -90,7 +96,7 @@
 extern int octave_tex_lex (YYSTYPE *, void *);
  static void yyerror (octave::text_parser_tex& parser, const char *s);
 
-#define scanner parser.get_scanner ()
+#define m_scanner parser.get_scanner ()
 #define yyalloc octave_tex_yyalloc
 
 #if defined (HAVE_PRAGMA_GCC_DIAGNOSTIC)
@@ -103,7 +109,7 @@ extern int octave_tex_lex (YYSTYPE *, void *);
 #endif
 
 
-#line 107 "libinterp/corefcn/oct-tex-parser.cc"
+#line 113 "libinterp/corefcn/oct-tex-parser.cc"
 
 # ifndef YY_CAST
 #  ifdef __cplusplus
@@ -126,114 +132,7 @@ extern int octave_tex_lex (YYSTYPE *, void *);
 #  endif
 # endif
 
-/* Use api.header.include to #include this header
-   instead of duplicating it here.  */
-#ifndef YY_OCTAVE_TEX_LIBINTERP_COREFCN_OCT_TEX_PARSER_H_INCLUDED
-# define YY_OCTAVE_TEX_LIBINTERP_COREFCN_OCT_TEX_PARSER_H_INCLUDED
-/* Debug traces.  */
-#ifndef OCTAVE_TEX_DEBUG
-# if defined YYDEBUG
-#if YYDEBUG
-#   define OCTAVE_TEX_DEBUG 1
-#  else
-#   define OCTAVE_TEX_DEBUG 0
-#  endif
-# else /* ! defined YYDEBUG */
-#  define OCTAVE_TEX_DEBUG 0
-# endif /* ! defined YYDEBUG */
-#endif  /* ! defined OCTAVE_TEX_DEBUG */
-#if OCTAVE_TEX_DEBUG
-extern int octave_tex_debug;
-#endif
-/* "%code requires" blocks.  */
-#line 62 "../libinterp/corefcn/oct-tex-parser.yy"
-#include <string>
-
-#line 153 "libinterp/corefcn/oct-tex-parser.cc"
-
-/* Token kinds.  */
-#ifndef OCTAVE_TEX_TOKENTYPE
-# define OCTAVE_TEX_TOKENTYPE
-  enum octave_tex_tokentype
-  {
-    OCTAVE_TEX_EMPTY = -2,
-    OCTAVE_TEX_EOF = 0,            /* "end of file"  */
-    OCTAVE_TEX_error = 256,        /* error  */
-    OCTAVE_TEX_UNDEF = 257,        /* "invalid token"  */
-    BF = 258,                      /* BF  */
-    IT = 259,                      /* IT  */
-    SL = 260,                      /* SL  */
-    RM = 261,                      /* RM  */
-    FONTNAME = 262,                /* FONTNAME  */
-    FONTSIZE = 263,                /* FONTSIZE  */
-    COLOR = 264,                   /* COLOR  */
-    COLOR_RGB = 265,               /* COLOR_RGB  */
-    START = 266,                   /* START  */
-    END = 267,                     /* END  */
-    SUPER = 268,                   /* SUPER  */
-    SUB = 269,                     /* SUB  */
-    CH = 270,                      /* CH  */
-    NUM = 271,                     /* NUM  */
-    SYM = 272,                     /* SYM  */
-    SCRIPT = 273,                  /* SCRIPT  */
-    STR = 274                      /* STR  */
-  };
-  typedef enum octave_tex_tokentype octave_tex_token_kind_t;
-#endif
-/* Token kinds.  */
-#define OCTAVE_TEX_EMPTY -2
-#define OCTAVE_TEX_EOF 0
-#define OCTAVE_TEX_error 256
-#define OCTAVE_TEX_UNDEF 257
-#define BF 258
-#define IT 259
-#define SL 260
-#define RM 261
-#define FONTNAME 262
-#define FONTSIZE 263
-#define COLOR 264
-#define COLOR_RGB 265
-#define START 266
-#define END 267
-#define SUPER 268
-#define SUB 269
-#define CH 270
-#define NUM 271
-#define SYM 272
-#define SCRIPT 273
-#define STR 274
-
-/* Value type.  */
-#if ! defined OCTAVE_TEX_STYPE && ! defined OCTAVE_TEX_STYPE_IS_DECLARED
-union OCTAVE_TEX_STYPE
-{
-#line 65 "../libinterp/corefcn/oct-tex-parser.yy"
-
-  // Leaf symbols produced by the scanner.
-  char ch;
-  double num;
-  int sym;
-
-  // Used for string buffering.
-  std::string *str;
-
-  // Objects produced by the parser.
-  octave::text_element *e_base;
-  octave::text_element_list *e_list;
-
-#line 225 "libinterp/corefcn/oct-tex-parser.cc"
-
-};
-typedef union OCTAVE_TEX_STYPE OCTAVE_TEX_STYPE;
-# define OCTAVE_TEX_STYPE_IS_TRIVIAL 1
-# define OCTAVE_TEX_STYPE_IS_DECLARED 1
-#endif
-
-
-
-int octave_tex_parse (octave::text_parser_tex& parser);
-
-#endif /* !YY_OCTAVE_TEX_LIBINTERP_COREFCN_OCT_TEX_PARSER_H_INCLUDED  */
+#include "oct-tex-parser.h"
 /* Symbol kind.  */
 enum yysymbol_kind_t
 {
@@ -429,12 +328,18 @@ typedef int yy_state_fast_t;
 # define YY_USE(E) /* empty */
 #endif
 
-#if defined __GNUC__ && ! defined __ICC && 407 <= __GNUC__ * 100 + __GNUC_MINOR__
 /* Suppress an incorrect diagnostic about yylval being uninitialized.  */
-# define YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN                            \
+#if defined __GNUC__ && ! defined __ICC && 406 <= __GNUC__ * 100 + __GNUC_MINOR__
+# if __GNUC__ * 100 + __GNUC_MINOR__ < 407
+#  define YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN                           \
+    _Pragma ("GCC diagnostic push")                                     \
+    _Pragma ("GCC diagnostic ignored \"-Wuninitialized\"")
+# else
+#  define YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN                           \
     _Pragma ("GCC diagnostic push")                                     \
     _Pragma ("GCC diagnostic ignored \"-Wuninitialized\"")              \
     _Pragma ("GCC diagnostic ignored \"-Wmaybe-uninitialized\"")
+# endif
 # define YY_IGNORE_MAYBE_UNINITIALIZED_END      \
     _Pragma ("GCC diagnostic pop")
 #else
@@ -467,30 +372,6 @@ typedef int yy_state_fast_t;
 
 /* The parser invokes alloca or malloc; define the necessary symbols.  */
 
-# ifdef YYSTACK_USE_ALLOCA
-#  if YYSTACK_USE_ALLOCA
-#   ifdef __GNUC__
-#    define YYSTACK_ALLOC __builtin_alloca
-#   elif defined __BUILTIN_VA_ARG_INCR
-#    include <alloca.h> /* INFRINGES ON USER NAME SPACE */
-#   elif defined _AIX
-#    define YYSTACK_ALLOC __alloca
-#   elif defined _MSC_VER
-#    include <malloc.h> /* INFRINGES ON USER NAME SPACE */
-#    define alloca _alloca
-#   else
-#    define YYSTACK_ALLOC alloca
-#    if ! defined _ALLOCA_H && ! defined EXIT_SUCCESS
-#     include <stdlib.h> /* INFRINGES ON USER NAME SPACE */
-      /* Use EXIT_SUCCESS as a witness for stdlib.h.  */
-#     ifndef EXIT_SUCCESS
-#      define EXIT_SUCCESS 0
-#     endif
-#    endif
-#   endif
-#  endif
-# endif
-
 # ifdef YYSTACK_ALLOC
    /* Pacify GCC's 'empty if-body' warning.  */
 #  define YYSTACK_FREE(Ptr) do { /* empty */; } while (0)
@@ -650,13 +531,13 @@ static const yytype_int8 yytranslate[] =
 };
 
 #if OCTAVE_TEX_DEBUG
-  /* YYRLINE[YYN] -- Source line where rule number YYN was defined.  */
+/* YYRLINE[YYN] -- Source line where rule number YYN was defined.  */
 static const yytype_uint8 yyrline[] =
 {
-       0,   108,   108,   110,   114,   118,   120,   122,   124,   128,
-     132,   139,   144,   150,   155,   157,   158,   159,   160,   161,
-     162,   163,   164,   167,   169,   171,   175,   177,   179,   183,
-     185,   189,   191,   196,   198,   203,   204
+       0,   109,   109,   111,   115,   119,   121,   123,   125,   129,
+     133,   140,   145,   151,   156,   158,   159,   160,   161,   162,
+     163,   164,   165,   168,   170,   172,   176,   178,   180,   184,
+     186,   190,   192,   197,   199,   204,   205
 };
 #endif
 
@@ -688,16 +569,6 @@ yysymbol_name (yysymbol_kind_t yysymbol)
 }
 #endif
 
-#ifdef YYPRINT
-/* YYTOKNUM[NUM] -- (External) token number corresponding to the
-   (internal) symbol number NUM (which must be that of a token).  */
-static const yytype_int16 yytoknum[] =
-{
-       0,   256,   257,   258,   259,   260,   261,   262,   263,   264,
-     265,   266,   267,   268,   269,   270,   271,   272,   273,   274
-};
-#endif
-
 #define YYPACT_NINF (-4)
 
 #define yypact_value_is_default(Yyn) \
@@ -708,8 +579,8 @@ static const yytype_int16 yytoknum[] =
 #define yytable_value_is_error(Yyn) \
   0
 
-  /* YYPACT[STATE-NUM] -- Index in YYTABLE of the portion describing
-     STATE-NUM.  */
+/* YYPACT[STATE-NUM] -- Index in YYTABLE of the portion describing
+   STATE-NUM.  */
 static const yytype_int8 yypact[] =
 {
       27,    -4,    -4,    -4,    -4,     2,    17,    32,    37,    -3,
@@ -720,9 +591,9 @@ static const yytype_int8 yypact[] =
       -4,    -4,    59,    62,    -4
 };
 
-  /* YYDEFACT[STATE-NUM] -- Default reduction number in state STATE-NUM.
-     Performed when YYTABLE does not specify something else to do.  Zero
-     means the default is an error.  */
+/* YYDEFACT[STATE-NUM] -- Default reduction number in state STATE-NUM.
+   Performed when YYTABLE does not specify something else to do.  Zero
+   means the default is an error.  */
 static const yytype_int8 yydefact[] =
 {
       35,     5,     6,     7,     8,     0,     0,     0,     0,     0,
@@ -733,23 +604,23 @@ static const yytype_int8 yydefact[] =
        9,    11,     0,     0,    12
 };
 
-  /* YYPGOTO[NTERM-NUM].  */
+/* YYPGOTO[NTERM-NUM].  */
 static const yytype_int8 yypgoto[] =
 {
       -4,    31,    51,    -4,    -4,    -4,    -4,    15,    46,    60,
       -4,    67,    53,    -4
 };
 
-  /* YYDEFGOTO[NTERM-NUM].  */
+/* YYDEFGOTO[NTERM-NUM].  */
 static const yytype_int8 yydefgoto[] =
 {
        0,    14,    15,    16,    17,    18,    19,    20,    21,    22,
       23,    24,    25,    26
 };
 
-  /* YYTABLE[YYPACT[STATE-NUM]] -- What to do in state STATE-NUM.  If
-     positive, shift that token.  If negative, reduce the rule whose
-     number is the opposite.  If YYTABLE_NINF, syntax error.  */
+/* YYTABLE[YYPACT[STATE-NUM]] -- What to do in state STATE-NUM.  If
+   positive, shift that token.  If negative, reduce the rule whose
+   number is the opposite.  If YYTABLE_NINF, syntax error.  */
 static const yytype_int8 yytable[] =
 {
        1,     2,     3,     4,     5,     6,     7,     8,     9,    31,
@@ -776,8 +647,8 @@ static const yytype_int8 yycheck[] =
       -1,    21
 };
 
-  /* YYSTOS[STATE-NUM] -- The (internal number of the) accessing
-     symbol of state STATE-NUM.  */
+/* YYSTOS[STATE-NUM] -- The symbol kind of the accessing symbol of
+   state STATE-NUM.  */
 static const yytype_int8 yystos[] =
 {
        0,     3,     4,     5,     6,     7,     8,     9,    10,    11,
@@ -788,7 +659,7 @@ static const yytype_int8 yystos[] =
       12,    12,    16,    16,    12
 };
 
-  /* YYR1[YYN] -- Symbol number of symbol that rule YYN derives.  */
+/* YYR1[RULE-NUM] -- Symbol kind of the left-hand side of rule RULE-NUM.  */
 static const yytype_int8 yyr1[] =
 {
        0,    20,    21,    21,    22,    23,    23,    23,    23,    24,
@@ -797,7 +668,7 @@ static const yytype_int8 yyr1[] =
       30,    31,    31,    32,    32,    33,    33
 };
 
-  /* YYR2[YYN] -- Number of symbols on the right hand side of rule YYN.  */
+/* YYR2[RULE-NUM] -- Number of symbols on the right-hand side of rule RULE-NUM.  */
 static const yytype_int8 yyr2[] =
 {
        0,     2,     1,     2,     1,     1,     1,     1,     1,     4,
@@ -815,6 +686,7 @@ enum { YYENOMEM = -2 };
 #define YYACCEPT        goto yyacceptlab
 #define YYABORT         goto yyabortlab
 #define YYERROR         goto yyerrorlab
+#define YYNOMEM         goto yyexhaustedlab
 
 
 #define YYRECOVERING()  (!!yyerrstatus)
@@ -855,10 +727,7 @@ do {                                            \
     YYFPRINTF Args;                             \
 } while (0)
 
-/* This macro is provided for backward compatibility. */
-# ifndef YY_LOCATION_PRINT
-#  define YY_LOCATION_PRINT(File, Loc) ((void) 0)
-# endif
+
 
 
 # define YY_SYMBOL_PRINT(Title, Kind, Value, Location)                    \
@@ -886,10 +755,6 @@ yy_symbol_value_print (FILE *yyo,
   YY_USE (parser);
   if (!yyvaluep)
     return;
-# ifdef YYPRINT
-  if (yykind < YYNTOKENS)
-    YYPRINT (yyo, yytoknum[yykind], *yyvaluep);
-# endif
   YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
   YY_USE (yykind);
   YY_IGNORE_MAYBE_UNINITIALIZED_END
@@ -991,6 +856,35 @@ int yydebug;
 #ifndef YYMAXDEPTH
 # define YYMAXDEPTH 10000
 #endif
+/* Parser data structure.  */
+struct yypstate
+  {
+    /* Number of syntax errors so far.  */
+    int yynerrs;
+
+    yy_state_fast_t yystate;
+    /* Number of tokens to shift before error messages enabled.  */
+    int yyerrstatus;
+
+    /* Refer to the stacks through separate pointers, to allow yyoverflow
+       to reallocate them elsewhere.  */
+
+    /* Their size.  */
+    YYPTRDIFF_T yystacksize;
+
+    /* The state stack: array, bottom, top.  */
+    yy_state_t yyssa[YYINITDEPTH];
+    yy_state_t *yyss;
+    yy_state_t *yyssp;
+
+    /* The semantic value stack: array, bottom, top.  */
+    YYSTYPE yyvsa[YYINITDEPTH];
+    YYSTYPE *yyvs;
+    YYSTYPE *yyvsp;
+    /* Whether this instance has not started parsing yet.
+     * If 2, it corresponds to a finished parsing.  */
+    int yynew;
+  };
 
 
 
@@ -1015,93 +909,93 @@ yydestruct (const char *yymsg,
   switch (yykind)
     {
     case YYSYMBOL_CH: /* CH  */
-#line 95 "../libinterp/corefcn/oct-tex-parser.yy"
+#line 96 "../libinterp/corefcn/oct-tex-parser.yy"
             { }
-#line 1021 "libinterp/corefcn/oct-tex-parser.cc"
+#line 915 "libinterp/corefcn/oct-tex-parser.cc"
         break;
 
     case YYSYMBOL_NUM: /* NUM  */
-#line 95 "../libinterp/corefcn/oct-tex-parser.yy"
+#line 96 "../libinterp/corefcn/oct-tex-parser.yy"
             { }
-#line 1027 "libinterp/corefcn/oct-tex-parser.cc"
+#line 921 "libinterp/corefcn/oct-tex-parser.cc"
         break;
 
     case YYSYMBOL_SYM: /* SYM  */
-#line 95 "../libinterp/corefcn/oct-tex-parser.yy"
+#line 96 "../libinterp/corefcn/oct-tex-parser.yy"
             { }
-#line 1033 "libinterp/corefcn/oct-tex-parser.cc"
+#line 927 "libinterp/corefcn/oct-tex-parser.cc"
         break;
 
     case YYSYMBOL_simple_string: /* simple_string  */
-#line 96 "../libinterp/corefcn/oct-tex-parser.yy"
+#line 97 "../libinterp/corefcn/oct-tex-parser.yy"
             { delete ((*yyvaluep).str); }
-#line 1039 "libinterp/corefcn/oct-tex-parser.cc"
+#line 933 "libinterp/corefcn/oct-tex-parser.cc"
         break;
 
     case YYSYMBOL_symbol_element: /* symbol_element  */
-#line 96 "../libinterp/corefcn/oct-tex-parser.yy"
+#line 97 "../libinterp/corefcn/oct-tex-parser.yy"
             { delete ((*yyvaluep).e_base); }
-#line 1045 "libinterp/corefcn/oct-tex-parser.cc"
+#line 939 "libinterp/corefcn/oct-tex-parser.cc"
         break;
 
     case YYSYMBOL_font_modifier_element: /* font_modifier_element  */
-#line 96 "../libinterp/corefcn/oct-tex-parser.yy"
+#line 97 "../libinterp/corefcn/oct-tex-parser.yy"
             { delete ((*yyvaluep).e_base); }
-#line 1051 "libinterp/corefcn/oct-tex-parser.cc"
+#line 945 "libinterp/corefcn/oct-tex-parser.cc"
         break;
 
     case YYSYMBOL_fontsize_element: /* fontsize_element  */
-#line 96 "../libinterp/corefcn/oct-tex-parser.yy"
+#line 97 "../libinterp/corefcn/oct-tex-parser.yy"
             { delete ((*yyvaluep).e_base); }
-#line 1057 "libinterp/corefcn/oct-tex-parser.cc"
+#line 951 "libinterp/corefcn/oct-tex-parser.cc"
         break;
 
     case YYSYMBOL_fontname_element: /* fontname_element  */
-#line 96 "../libinterp/corefcn/oct-tex-parser.yy"
+#line 97 "../libinterp/corefcn/oct-tex-parser.yy"
             { delete ((*yyvaluep).e_base); }
-#line 1063 "libinterp/corefcn/oct-tex-parser.cc"
+#line 957 "libinterp/corefcn/oct-tex-parser.cc"
         break;
 
     case YYSYMBOL_color_element: /* color_element  */
-#line 96 "../libinterp/corefcn/oct-tex-parser.yy"
+#line 97 "../libinterp/corefcn/oct-tex-parser.yy"
             { delete ((*yyvaluep).e_base); }
-#line 1069 "libinterp/corefcn/oct-tex-parser.cc"
+#line 963 "libinterp/corefcn/oct-tex-parser.cc"
         break;
 
     case YYSYMBOL_string_element: /* string_element  */
-#line 96 "../libinterp/corefcn/oct-tex-parser.yy"
+#line 97 "../libinterp/corefcn/oct-tex-parser.yy"
             { delete ((*yyvaluep).e_base); }
-#line 1075 "libinterp/corefcn/oct-tex-parser.cc"
+#line 969 "libinterp/corefcn/oct-tex-parser.cc"
         break;
 
     case YYSYMBOL_superscript_element: /* superscript_element  */
-#line 96 "../libinterp/corefcn/oct-tex-parser.yy"
+#line 97 "../libinterp/corefcn/oct-tex-parser.yy"
             { delete ((*yyvaluep).e_base); }
-#line 1081 "libinterp/corefcn/oct-tex-parser.cc"
+#line 975 "libinterp/corefcn/oct-tex-parser.cc"
         break;
 
     case YYSYMBOL_subscript_element: /* subscript_element  */
-#line 96 "../libinterp/corefcn/oct-tex-parser.yy"
+#line 97 "../libinterp/corefcn/oct-tex-parser.yy"
             { delete ((*yyvaluep).e_base); }
-#line 1087 "libinterp/corefcn/oct-tex-parser.cc"
+#line 981 "libinterp/corefcn/oct-tex-parser.cc"
         break;
 
     case YYSYMBOL_combined_script_element: /* combined_script_element  */
-#line 96 "../libinterp/corefcn/oct-tex-parser.yy"
+#line 97 "../libinterp/corefcn/oct-tex-parser.yy"
             { delete ((*yyvaluep).e_base); }
-#line 1093 "libinterp/corefcn/oct-tex-parser.cc"
+#line 987 "libinterp/corefcn/oct-tex-parser.cc"
         break;
 
     case YYSYMBOL_string_element_list: /* string_element_list  */
-#line 96 "../libinterp/corefcn/oct-tex-parser.yy"
+#line 97 "../libinterp/corefcn/oct-tex-parser.yy"
             { delete ((*yyvaluep).e_list); }
-#line 1099 "libinterp/corefcn/oct-tex-parser.cc"
+#line 993 "libinterp/corefcn/oct-tex-parser.cc"
         break;
 
     case YYSYMBOL_scoped_string_element_list: /* scoped_string_element_list  */
-#line 96 "../libinterp/corefcn/oct-tex-parser.yy"
+#line 97 "../libinterp/corefcn/oct-tex-parser.yy"
             { delete ((*yyvaluep).e_list); }
-#line 1105 "libinterp/corefcn/oct-tex-parser.cc"
+#line 999 "libinterp/corefcn/oct-tex-parser.cc"
         break;
 
       default:
@@ -1114,13 +1008,100 @@ yydestruct (const char *yymsg,
 
 
 
-
-/*----------.
-| yyparse.  |
-`----------*/
-
 int
 yyparse (octave::text_parser_tex& parser)
+{
+  yypstate *yyps = yypstate_new ();
+  if (!yyps)
+    {
+      yyerror (parser, YY_("memory exhausted"));
+      return 2;
+    }
+  int yystatus = yypull_parse (yyps, parser);
+  yypstate_delete (yyps);
+  return yystatus;
+}
+
+int
+yypull_parse (yypstate *yyps, octave::text_parser_tex& parser)
+{
+  YY_ASSERT (yyps);
+  int yystatus;
+  do {
+    YYSTYPE yylval;
+    int yychar = yylex (&yylval, m_scanner);
+    yystatus = yypush_parse (yyps, yychar, &yylval, parser);
+  } while (yystatus == YYPUSH_MORE);
+  return yystatus;
+}
+
+#define octave_tex_nerrs yyps->octave_tex_nerrs
+#define yystate yyps->yystate
+#define yyerrstatus yyps->yyerrstatus
+#define yyssa yyps->yyssa
+#define yyss yyps->yyss
+#define yyssp yyps->yyssp
+#define yyvsa yyps->yyvsa
+#define yyvs yyps->yyvs
+#define yyvsp yyps->yyvsp
+#define yystacksize yyps->yystacksize
+
+/* Initialize the parser data structure.  */
+static void
+yypstate_clear (yypstate *yyps)
+{
+  yynerrs = 0;
+  yystate = 0;
+  yyerrstatus = 0;
+
+  yyssp = yyss;
+  yyvsp = yyvs;
+
+  /* Initialize the state stack, in case yypcontext_expected_tokens is
+     called before the first call to yyparse. */
+  *yyssp = 0;
+  yyps->yynew = 1;
+}
+
+/* Initialize the parser data structure.  */
+yypstate *
+yypstate_new (void)
+{
+  yypstate *yyps;
+  yyps = YY_CAST (yypstate *, YYMALLOC (sizeof *yyps));
+  if (!yyps)
+    return YY_NULLPTR;
+  yystacksize = YYINITDEPTH;
+  yyss = yyssa;
+  yyvs = yyvsa;
+  yypstate_clear (yyps);
+  return yyps;
+}
+
+void
+yypstate_delete (yypstate *yyps)
+{
+  if (yyps)
+    {
+#ifndef yyoverflow
+      /* If the stack was reallocated but the parse did not complete, then the
+         stack still needs to be freed.  */
+      if (yyss != yyssa)
+        YYSTACK_FREE (yyss);
+#endif
+      YYFREE (yyps);
+    }
+}
+
+
+
+/*---------------.
+| yypush_parse.  |
+`---------------*/
+
+int
+yypush_parse (yypstate *yyps,
+              int yypushed_char, YYSTYPE const *yypushed_val, octave::text_parser_tex& parser)
 {
 /* Lookahead token kind.  */
 int yychar;
@@ -1132,29 +1113,6 @@ int yychar;
 YY_INITIAL_VALUE (static YYSTYPE yyval_default;)
 YYSTYPE yylval YY_INITIAL_VALUE (= yyval_default);
 
-    /* Number of syntax errors so far.  */
-    int yynerrs = 0;
-
-    yy_state_fast_t yystate = 0;
-    /* Number of tokens to shift before error messages enabled.  */
-    int yyerrstatus = 0;
-
-    /* Refer to the stacks through separate pointers, to allow yyoverflow
-       to reallocate them elsewhere.  */
-
-    /* Their size.  */
-    YYPTRDIFF_T yystacksize = YYINITDEPTH;
-
-    /* The state stack: array, bottom, top.  */
-    yy_state_t yyssa[YYINITDEPTH];
-    yy_state_t *yyss = yyssa;
-    yy_state_t *yyssp = yyss;
-
-    /* The semantic value stack: array, bottom, top.  */
-    YYSTYPE yyvsa[YYINITDEPTH];
-    YYSTYPE *yyvs = yyvsa;
-    YYSTYPE *yyvsp = yyvs;
-
   int yyn;
   /* The return value of yyparse.  */
   int yyresult;
@@ -1172,9 +1130,24 @@ YYSTYPE yylval YY_INITIAL_VALUE (= yyval_default);
      Keep to zero when no symbol should be popped.  */
   int yylen = 0;
 
+  switch (yyps->yynew)
+    {
+    case 0:
+      yyn = yypact[yystate];
+      goto yyread_pushed_token;
+
+    case 2:
+      yypstate_clear (yyps);
+      break;
+
+    default:
+      break;
+    }
+
   YYDPRINTF ((stderr, "Starting parse\n"));
 
   yychar = OCTAVE_TEX_EMPTY; /* Cause a token to be read.  */
+
   goto yysetstate;
 
 
@@ -1200,7 +1173,7 @@ yysetstate:
 
   if (yyss + yystacksize - 1 <= yyssp)
 #if !defined yyoverflow && !defined YYSTACK_RELOCATE
-    goto yyexhaustedlab;
+    YYNOMEM;
 #else
     {
       /* Get the current used size of the three stacks, in elements.  */
@@ -1228,7 +1201,7 @@ yysetstate:
 # else /* defined YYSTACK_RELOCATE */
       /* Extend the stack our own way.  */
       if (YYMAXDEPTH <= yystacksize)
-        goto yyexhaustedlab;
+        YYNOMEM;
       yystacksize *= 2;
       if (YYMAXDEPTH < yystacksize)
         yystacksize = YYMAXDEPTH;
@@ -1239,7 +1212,7 @@ yysetstate:
           YY_CAST (union yyalloc *,
                    YYSTACK_ALLOC (YY_CAST (YYSIZE_T, YYSTACK_BYTES (yystacksize))));
         if (! yyptr)
-          goto yyexhaustedlab;
+          YYNOMEM;
         YYSTACK_RELOCATE (yyss_alloc, yyss);
         YYSTACK_RELOCATE (yyvs_alloc, yyvs);
 #  undef YYSTACK_RELOCATE
@@ -1261,6 +1234,7 @@ yysetstate:
     }
 #endif /* !defined yyoverflow && !defined YYSTACK_RELOCATE */
 
+
   if (yystate == YYFINAL)
     YYACCEPT;
 
@@ -1284,8 +1258,18 @@ yybackup:
   /* YYCHAR is either empty, or end-of-input, or a valid lookahead.  */
   if (yychar == OCTAVE_TEX_EMPTY)
     {
+      if (!yyps->yynew)
+        {
+          YYDPRINTF ((stderr, "Return for a new token:\n"));
+          yyresult = YYPUSH_MORE;
+          goto yypushreturn;
+        }
+      yyps->yynew = 0;
+yyread_pushed_token:
       YYDPRINTF ((stderr, "Reading a token\n"));
-      yychar = yylex (&yylval, scanner);
+      yychar = yypushed_char;
+      if (yypushed_val)
+        yylval = *yypushed_val;
     }
 
   if (yychar <= OCTAVE_TEX_EOF)
@@ -1373,180 +1357,180 @@ yyreduce:
   switch (yyn)
     {
   case 2: /* simple_string: CH  */
-#line 109 "../libinterp/corefcn/oct-tex-parser.yy"
+#line 110 "../libinterp/corefcn/oct-tex-parser.yy"
                           { (yyval.str) = new std::string (1, (yyvsp[0].ch)); }
-#line 1379 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1363 "libinterp/corefcn/oct-tex-parser.cc"
     break;
 
   case 3: /* simple_string: simple_string CH  */
-#line 111 "../libinterp/corefcn/oct-tex-parser.yy"
+#line 112 "../libinterp/corefcn/oct-tex-parser.yy"
                           { (yyvsp[-1].str)->append (1, (yyvsp[0].ch)); (yyval.str) = (yyvsp[-1].str); }
-#line 1385 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1369 "libinterp/corefcn/oct-tex-parser.cc"
     break;
 
   case 4: /* symbol_element: SYM  */
-#line 115 "../libinterp/corefcn/oct-tex-parser.yy"
+#line 116 "../libinterp/corefcn/oct-tex-parser.yy"
                           { (yyval.e_base) = new octave::text_element_symbol ((yyvsp[0].sym)); }
-#line 1391 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1375 "libinterp/corefcn/oct-tex-parser.cc"
     break;
 
   case 5: /* font_modifier_element: BF  */
-#line 119 "../libinterp/corefcn/oct-tex-parser.yy"
+#line 120 "../libinterp/corefcn/oct-tex-parser.yy"
                           { (yyval.e_base) = new octave::text_element_fontstyle (octave::text_element_fontstyle::bold); }
-#line 1397 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1381 "libinterp/corefcn/oct-tex-parser.cc"
     break;
 
   case 6: /* font_modifier_element: IT  */
-#line 121 "../libinterp/corefcn/oct-tex-parser.yy"
+#line 122 "../libinterp/corefcn/oct-tex-parser.yy"
                           { (yyval.e_base) = new octave::text_element_fontstyle (octave::text_element_fontstyle::italic); }
-#line 1403 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1387 "libinterp/corefcn/oct-tex-parser.cc"
     break;
 
   case 7: /* font_modifier_element: SL  */
-#line 123 "../libinterp/corefcn/oct-tex-parser.yy"
+#line 124 "../libinterp/corefcn/oct-tex-parser.yy"
                           { (yyval.e_base) = new octave::text_element_fontstyle (octave::text_element_fontstyle::oblique); }
-#line 1409 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1393 "libinterp/corefcn/oct-tex-parser.cc"
     break;
 
   case 8: /* font_modifier_element: RM  */
-#line 125 "../libinterp/corefcn/oct-tex-parser.yy"
+#line 126 "../libinterp/corefcn/oct-tex-parser.yy"
                           { (yyval.e_base) = new octave::text_element_fontstyle (octave::text_element_fontstyle::normal); }
-#line 1415 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1399 "libinterp/corefcn/oct-tex-parser.cc"
     break;
 
   case 9: /* fontsize_element: FONTSIZE START NUM END  */
-#line 129 "../libinterp/corefcn/oct-tex-parser.yy"
+#line 130 "../libinterp/corefcn/oct-tex-parser.yy"
                           { (yyval.e_base) = new octave::text_element_fontsize ((yyvsp[-1].num)); }
-#line 1421 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1405 "libinterp/corefcn/oct-tex-parser.cc"
     break;
 
   case 10: /* fontname_element: FONTNAME START simple_string END  */
-#line 133 "../libinterp/corefcn/oct-tex-parser.yy"
+#line 134 "../libinterp/corefcn/oct-tex-parser.yy"
                           {
                             (yyval.e_base) = new octave::text_element_fontname (*(yyvsp[-1].str));
                             delete (yyvsp[-1].str);
                           }
-#line 1430 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1414 "libinterp/corefcn/oct-tex-parser.cc"
     break;
 
   case 11: /* color_element: COLOR START simple_string END  */
-#line 140 "../libinterp/corefcn/oct-tex-parser.yy"
+#line 141 "../libinterp/corefcn/oct-tex-parser.yy"
                           {
                             (yyval.e_base) = new octave::text_element_color (*(yyvsp[-1].str));
                             delete (yyvsp[-1].str);
                           }
-#line 1439 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1423 "libinterp/corefcn/oct-tex-parser.cc"
     break;
 
   case 12: /* color_element: COLOR_RGB START NUM NUM NUM END  */
-#line 145 "../libinterp/corefcn/oct-tex-parser.yy"
+#line 146 "../libinterp/corefcn/oct-tex-parser.yy"
                           {
                             (yyval.e_base) = new octave::text_element_color ((yyvsp[-3].num), (yyvsp[-2].num), (yyvsp[-1].num));
                           }
-#line 1447 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1431 "libinterp/corefcn/oct-tex-parser.cc"
     break;
 
   case 13: /* string_element: simple_string  */
-#line 151 "../libinterp/corefcn/oct-tex-parser.yy"
+#line 152 "../libinterp/corefcn/oct-tex-parser.yy"
                           {
                             (yyval.e_base) = new octave::text_element_string (*(yyvsp[0].str));
                             delete (yyvsp[0].str);
                           }
-#line 1456 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1440 "libinterp/corefcn/oct-tex-parser.cc"
     break;
 
   case 14: /* string_element: scoped_string_element_list  */
-#line 156 "../libinterp/corefcn/oct-tex-parser.yy"
+#line 157 "../libinterp/corefcn/oct-tex-parser.yy"
                           { (yyval.e_base) = (yyvsp[0].e_list); }
-#line 1462 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1446 "libinterp/corefcn/oct-tex-parser.cc"
     break;
 
   case 23: /* superscript_element: SUPER CH  */
-#line 168 "../libinterp/corefcn/oct-tex-parser.yy"
+#line 169 "../libinterp/corefcn/oct-tex-parser.yy"
                           { (yyval.e_base) = new octave::text_element_superscript ((yyvsp[0].ch)); }
-#line 1468 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1452 "libinterp/corefcn/oct-tex-parser.cc"
     break;
 
   case 24: /* superscript_element: SUPER scoped_string_element_list  */
-#line 170 "../libinterp/corefcn/oct-tex-parser.yy"
+#line 171 "../libinterp/corefcn/oct-tex-parser.yy"
                           { (yyval.e_base) = new octave::text_element_superscript ((yyvsp[0].e_list)); }
-#line 1474 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1458 "libinterp/corefcn/oct-tex-parser.cc"
     break;
 
   case 25: /* superscript_element: SUPER symbol_element  */
-#line 172 "../libinterp/corefcn/oct-tex-parser.yy"
+#line 173 "../libinterp/corefcn/oct-tex-parser.yy"
                           { (yyval.e_base) = new octave::text_element_superscript ((yyvsp[0].e_base)); }
-#line 1480 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1464 "libinterp/corefcn/oct-tex-parser.cc"
     break;
 
   case 26: /* subscript_element: SUB CH  */
-#line 176 "../libinterp/corefcn/oct-tex-parser.yy"
+#line 177 "../libinterp/corefcn/oct-tex-parser.yy"
                           { (yyval.e_base) = new octave::text_element_subscript ((yyvsp[0].ch)); }
-#line 1486 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1470 "libinterp/corefcn/oct-tex-parser.cc"
     break;
 
   case 27: /* subscript_element: SUB scoped_string_element_list  */
-#line 178 "../libinterp/corefcn/oct-tex-parser.yy"
+#line 179 "../libinterp/corefcn/oct-tex-parser.yy"
                           { (yyval.e_base) = new octave::text_element_subscript ((yyvsp[0].e_list)); }
-#line 1492 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1476 "libinterp/corefcn/oct-tex-parser.cc"
     break;
 
   case 28: /* subscript_element: SUB symbol_element  */
-#line 180 "../libinterp/corefcn/oct-tex-parser.yy"
+#line 181 "../libinterp/corefcn/oct-tex-parser.yy"
                           { (yyval.e_base) = new octave::text_element_subscript ((yyvsp[0].e_base)); }
-#line 1498 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1482 "libinterp/corefcn/oct-tex-parser.cc"
     break;
 
   case 29: /* combined_script_element: subscript_element superscript_element  */
-#line 184 "../libinterp/corefcn/oct-tex-parser.yy"
+#line 185 "../libinterp/corefcn/oct-tex-parser.yy"
                           { (yyval.e_base) = new octave::text_element_combined ((yyvsp[-1].e_base), (yyvsp[0].e_base)); }
-#line 1504 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1488 "libinterp/corefcn/oct-tex-parser.cc"
     break;
 
   case 30: /* combined_script_element: superscript_element subscript_element  */
-#line 186 "../libinterp/corefcn/oct-tex-parser.yy"
+#line 187 "../libinterp/corefcn/oct-tex-parser.yy"
                           { (yyval.e_base) = new octave::text_element_combined ((yyvsp[-1].e_base), (yyvsp[0].e_base)); }
-#line 1510 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1494 "libinterp/corefcn/oct-tex-parser.cc"
     break;
 
   case 31: /* string_element_list: string_element  */
-#line 190 "../libinterp/corefcn/oct-tex-parser.yy"
+#line 191 "../libinterp/corefcn/oct-tex-parser.yy"
                           { (yyval.e_list) = new octave::text_element_list ((yyvsp[0].e_base)); }
-#line 1516 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1500 "libinterp/corefcn/oct-tex-parser.cc"
     break;
 
   case 32: /* string_element_list: string_element_list string_element  */
-#line 192 "../libinterp/corefcn/oct-tex-parser.yy"
+#line 193 "../libinterp/corefcn/oct-tex-parser.yy"
                           { (yyvsp[-1].e_list)->push_back ((yyvsp[0].e_base)); (yyval.e_list) = (yyvsp[-1].e_list); }
-#line 1522 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1506 "libinterp/corefcn/oct-tex-parser.cc"
     break;
 
   case 33: /* scoped_string_element_list: START string_element_list END  */
-#line 197 "../libinterp/corefcn/oct-tex-parser.yy"
+#line 198 "../libinterp/corefcn/oct-tex-parser.yy"
                           { (yyval.e_list) = (yyvsp[-1].e_list); }
-#line 1528 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1512 "libinterp/corefcn/oct-tex-parser.cc"
     break;
 
   case 34: /* scoped_string_element_list: START END  */
-#line 199 "../libinterp/corefcn/oct-tex-parser.yy"
+#line 200 "../libinterp/corefcn/oct-tex-parser.yy"
                           { (yyval.e_list) = new octave::text_element_list (); }
-#line 1534 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1518 "libinterp/corefcn/oct-tex-parser.cc"
     break;
 
   case 35: /* string: %empty  */
-#line 203 "../libinterp/corefcn/oct-tex-parser.yy"
+#line 204 "../libinterp/corefcn/oct-tex-parser.yy"
                           { parser.set_parse_result (new octave::text_element_string ("")); }
-#line 1540 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1524 "libinterp/corefcn/oct-tex-parser.cc"
     break;
 
   case 36: /* string: string_element_list  */
-#line 205 "../libinterp/corefcn/oct-tex-parser.yy"
+#line 206 "../libinterp/corefcn/oct-tex-parser.yy"
                           { parser.set_parse_result ((yyvsp[0].e_list)); }
-#line 1546 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1530 "libinterp/corefcn/oct-tex-parser.cc"
     break;
 
 
-#line 1550 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1534 "libinterp/corefcn/oct-tex-parser.cc"
 
       default: break;
     }
@@ -1628,6 +1612,7 @@ yyerrorlab:
      label yyerrorlab therefore never appears in user code.  */
   if (0)
     YYERROR;
+  ++yynerrs;
 
   /* Do not reclaim the symbols of the rule whose action triggered
      this YYERROR.  */
@@ -1688,7 +1673,7 @@ yyerrlab1:
 `-------------------------------------*/
 yyacceptlab:
   yyresult = 0;
-  goto yyreturn;
+  goto yyreturnlab;
 
 
 /*-----------------------------------.
@@ -1696,24 +1681,22 @@ yyacceptlab:
 `-----------------------------------*/
 yyabortlab:
   yyresult = 1;
-  goto yyreturn;
+  goto yyreturnlab;
 
 
-#if !defined yyoverflow
-/*-------------------------------------------------.
-| yyexhaustedlab -- memory exhaustion comes here.  |
-`-------------------------------------------------*/
+/*-----------------------------------------------------------.
+| yyexhaustedlab -- YYNOMEM (memory exhaustion) comes here.  |
+`-----------------------------------------------------------*/
 yyexhaustedlab:
   yyerror (parser, YY_("memory exhausted"));
   yyresult = 2;
-  goto yyreturn;
-#endif
+  goto yyreturnlab;
 
 
-/*-------------------------------------------------------.
-| yyreturn -- parsing is finished, clean up and return.  |
-`-------------------------------------------------------*/
-yyreturn:
+/*----------------------------------------------------------.
+| yyreturnlab -- parsing is finished, clean up and return.  |
+`----------------------------------------------------------*/
+yyreturnlab:
   if (yychar != OCTAVE_TEX_EMPTY)
     {
       /* Make sure we have latest lookahead translation.  See comments at
@@ -1732,15 +1715,28 @@ yyreturn:
                   YY_ACCESSING_SYMBOL (+*yyssp), yyvsp, parser);
       YYPOPSTACK (1);
     }
-#ifndef yyoverflow
-  if (yyss != yyssa)
-    YYSTACK_FREE (yyss);
-#endif
+  yyps->yynew = 2;
+  goto yypushreturn;
+
+
+/*-------------------------.
+| yypushreturn -- return.  |
+`-------------------------*/
+yypushreturn:
 
   return yyresult;
 }
-
-#line 208 "../libinterp/corefcn/oct-tex-parser.yy"
+#undef octave_tex_nerrs
+#undef yystate
+#undef yyerrstatus
+#undef yyssa
+#undef yyss
+#undef yyssp
+#undef yyvsa
+#undef yyvs
+#undef yyvsp
+#undef yystacksize
+#line 209 "../libinterp/corefcn/oct-tex-parser.yy"
 
 
 #if defined (HAVE_PRAGMA_GCC_DIAGNOSTIC)
@@ -1748,8 +1744,8 @@ yyreturn:
 #  pragma GCC diagnostic pop
 #endif
 
-namespace octave
-{
+OCTAVE_BEGIN_NAMESPACE(octave)
+
   text_element*
   text_parser_tex::parse (const std::string& s)
   {
@@ -1757,15 +1753,16 @@ namespace octave
 
     if (init_lexer (s))
       {
-        result = nullptr;
+        m_result = nullptr;
 
         if (octave_tex_parse (*this) == 0)
-          return result;
+          return m_result;
       }
 
     return new text_element_string (s);
   }
-}
+
+OCTAVE_END_NAMESPACE(octave)
 
 static void
 yyerror (octave::text_parser_tex&, const char *s)
