@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////
 //
-// Copyright (C) 1996-2024 The Octave Project Developers
+// Copyright (C) 1996-2025 The Octave Project Developers
 //
 // See the file COPYRIGHT.md in the top-level directory of this
 // distribution or <https://octave.org/copyright/>.
@@ -100,9 +100,6 @@ std::string btyp_class_name[btyp_num_types+1] =
 DEFINE_OV_TYPEID_FUNCTIONS_AND_DATA (octave_base_value,
                                      "<unknown type>", "unknown");
 
-// DEPRECATED in Octave 8.
-bool Vsparse_auto_mutate = false;
-
 #if defined (HAVE_PRAGMA_GCC_DIAGNOSTIC)
    // Disable this warning for the use of the "count" member variable in
    // the default constructor.  Push the current state so we can restore
@@ -111,7 +108,7 @@ bool Vsparse_auto_mutate = false;
 #  pragma GCC diagnostic ignored "-Wdeprecated-declarations"
 #endif
 
-  octave_base_value::octave_base_value () : m_count (1), count (m_count) { }
+octave_base_value::octave_base_value () : m_count (1), count (m_count) { }
 
 #if defined (HAVE_PRAGMA_GCC_DIAGNOSTIC)
 #  pragma GCC diagnostic pop
@@ -161,7 +158,7 @@ octave_base_value::as_double () const
 octave_value
 octave_base_value::as_double_or_copy ()
 {
-  const octave_base_value * cthis = this;
+  const octave_base_value *cthis = this;
   return cthis->as_double ();
 }
 
@@ -343,7 +340,7 @@ octave_base_value::subsasgn (const std::string& type,
           break;
 
         default:
-          panic_impossible ();
+          error ("unexpected: index not '(', '{', or '.' in octave_base_value::subsasgn - please report this bug");
         }
     }
   else
@@ -532,8 +529,8 @@ octave_base_value::print_info (std::ostream& os,
         err_wrong_type_arg (ee, "octave_base_value::" #F "_value ()", type_name ()); \
       }                                                                 \
                                                                         \
-    static const double out_of_range_top                                \
-      = static_cast<double> (std::numeric_limits<T>::max ()) + 1.;      \
+    static constexpr double out_of_range_top                            \
+      = static_cast<double> (std::numeric_limits<T>::max ()) + 1.0;     \
     if (require_int && octave::math::x_nint (d) != d)                   \
       error_with_cfn ("conversion of %g to " #T " value failed", d);    \
     else if (d < std::numeric_limits<T>::min ())                        \
@@ -859,9 +856,7 @@ octave_base_value::string_value (bool force) const
 std::string
 octave_base_value::xstring_value () const
 {
-  wrong_type_arg_error ();
-
-  return std::string ();
+  err_wrong_type_arg ("octave_base_value::xstring_value()", type_name ());
 }
 
 Array<std::string>
@@ -1171,12 +1166,6 @@ octave_base_value::warn_save (const char *type) const
    s_t_name.c_str (), type);
 }
 
-void
-octave_base_value::wrong_type_arg_error () const
-{
-  err_wrong_type_arg (type_name ());
-}
-
 octave_value
 octave_base_value::map (unary_mapper_t umap) const
 {
@@ -1507,7 +1496,7 @@ make_idx_args (const std::string& type,
           break;
 
         default:
-          panic_impossible ();
+          error ("unexpected: index not '(', '{', or '.' in make_idx_args - please report this bug");
           break;
         }
     }
