@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////
 //
-// Copyright (C) 1998-2023 The Octave Project Developers
+// Copyright (C) 1998-2025 The Octave Project Developers
 //
 // See the file COPYRIGHT.md in the top-level directory of this
 // distribution or <https://octave.org/copyright/>.
@@ -36,9 +36,6 @@
 #include "oct-locbuf.h"
 
 #include "mxarray.h"
-#include "ov-base.h"
-#include "ov-scalar.h"
-#include "ov-complex.h"
 #include "errwarn.h"
 
 #include "oct-hdf5.h"
@@ -51,14 +48,11 @@
 
 #include "ov-bool-sparse.h"
 
-
-template class octave_base_sparse<SparseComplexMatrix>;
-
 DEFINE_OV_TYPEID_FUNCTIONS_AND_DATA (octave_sparse_complex_matrix,
                                      "sparse complex matrix", "double");
 
 octave_base_value *
-octave_sparse_complex_matrix::try_narrowing_conversion (void)
+octave_sparse_complex_matrix::try_narrowing_conversion ()
 {
   return (matrix.all_elements_are_real ()
           ? new octave_sparse_matrix (::real (matrix)) : nullptr);
@@ -173,7 +167,7 @@ octave_sparse_complex_matrix::sparse_bool_matrix_value (bool warn) const
 }
 
 octave_value
-octave_sparse_complex_matrix::as_double (void) const
+octave_sparse_complex_matrix::as_double () const
 {
   return this->matrix;
 }
@@ -182,7 +176,7 @@ bool
 octave_sparse_complex_matrix::save_binary (std::ostream& os,
     bool save_as_floats)
 {
-  dim_vector dv = this->dims ();
+  const dim_vector& dv = this->dims ();
   if (dv.ndims () < 1)
     return false;
 
@@ -327,7 +321,7 @@ octave_sparse_complex_matrix::save_hdf5 (octave_hdf5_id loc_id,
 
 #if defined (HAVE_HDF5)
 
-  dim_vector dv = dims ();
+  const dim_vector& dv = dims ();
   int empty = save_hdf5_empty (loc_id, name, dv);
   if (empty)
     return (empty > 0);
