@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////
 //
-// Copyright (C) 1998-2023 The Octave Project Developers
+// Copyright (C) 1998-2025 The Octave Project Developers
 //
 // See the file COPYRIGHT.md in the top-level directory of this
 // distribution or <https://octave.org/copyright/>.
@@ -27,7 +27,6 @@
 // C++ source files that should have included config.h before including
 // this file.
 
-#include <cassert>
 #include <cinttypes>
 
 #include <algorithm>
@@ -54,7 +53,7 @@
 
 template <typename T, typename Alloc>
 OCTAVE_API typename Sparse<T, Alloc>::SparseRep *
-Sparse<T, Alloc>::nil_rep (void)
+Sparse<T, Alloc>::nil_rep ()
 {
   static typename Sparse<T, Alloc>::SparseRep nr;
   return &nr;
@@ -150,9 +149,9 @@ Sparse<T, Alloc>::SparseRep::change_length (octave_idx_type nz)
   // Always preserve space for 1 element.
   nz = (nz > 0 ? nz : 1);
 
-  // Skip reallocation if we have less than 1/frac extra elements to discard.
-  static const int frac = 5;
-  if (nz > m_nzmax || nz < m_nzmax - m_nzmax/frac)
+  // Skip reallocation if we have less than 1/FRAC extra elements to discard.
+  static const int FRAC = 5;
+  if (nz > m_nzmax || nz < m_nzmax - m_nzmax/FRAC)
     {
       // Reallocate.
       octave_idx_type min_nzmax = std::min (nz, m_nzmax);
@@ -176,7 +175,7 @@ Sparse<T, Alloc>::SparseRep::change_length (octave_idx_type nz)
 template <typename T, typename Alloc>
 OCTAVE_API
 bool
-Sparse<T, Alloc>::SparseRep::indices_ok (void) const
+Sparse<T, Alloc>::SparseRep::indices_ok () const
 {
   return sparse_indices_ok (m_ridx, m_cidx, m_nrows, m_ncols, nnz ());
 }
@@ -184,7 +183,7 @@ Sparse<T, Alloc>::SparseRep::indices_ok (void) const
 template <typename T, typename Alloc>
 OCTAVE_API
 bool
-Sparse<T, Alloc>::SparseRep::any_element_is_nan (void) const
+Sparse<T, Alloc>::SparseRep::any_element_is_nan () const
 {
   octave_idx_type nz = nnz ();
 
@@ -197,8 +196,7 @@ Sparse<T, Alloc>::SparseRep::any_element_is_nan (void) const
 
 template <typename T, typename Alloc>
 OCTAVE_API
-Sparse<T, Alloc>::Sparse (octave_idx_type nr, octave_idx_type nc,
-                                        T val)
+Sparse<T, Alloc>::Sparse (octave_idx_type nr, octave_idx_type nc, T val)
   : m_rep (nullptr), m_dimensions (dim_vector (nr, nc))
 {
   if (val != T ())
@@ -263,16 +261,16 @@ Sparse<T, Alloc>::Sparse (const Sparse<T, Alloc>& a, const dim_vector& dv)
 {
 
   // Work in unsigned long long to avoid overflow issues with numel
-  unsigned long long a_nel = static_cast<unsigned long long>(a.rows ()) *
-                             static_cast<unsigned long long>(a.cols ());
-  unsigned long long dv_nel = static_cast<unsigned long long>(dv(0)) *
-                              static_cast<unsigned long long>(dv(1));
+  unsigned long long a_nel = static_cast<unsigned long long> (a.rows ()) *
+                             static_cast<unsigned long long> (a.cols ());
+  unsigned long long dv_nel = static_cast<unsigned long long> (dv(0)) *
+                              static_cast<unsigned long long> (dv(1));
 
   if (a_nel != dv_nel)
     (*current_liboctave_error_handler)
       ("Sparse::Sparse (const Sparse&, const dim_vector&): dimension mismatch");
 
-  dim_vector old_dims = a.dims ();
+  const dim_vector& old_dims = a.dims ();
   octave_idx_type new_nzmax = a.nnz ();
   octave_idx_type new_nr = dv(0);
   octave_idx_type new_nc = dv(1);
@@ -320,7 +318,7 @@ Sparse<T, Alloc>::Sparse (const Array<T>& a,
   else if (c.extent (nc) > nc)
     (*current_liboctave_error_handler)
       ("sparse: column index %" OCTAVE_IDX_TYPE_FORMAT " out of bound "
-       "%" OCTAVE_IDX_TYPE_FORMAT, r.extent (nc), nc);
+       "%" OCTAVE_IDX_TYPE_FORMAT, c.extent (nc), nc);
 
   m_dimensions = dim_vector (nr, nc);
 
@@ -705,7 +703,7 @@ Sparse<T, Alloc>::Sparse (const Array<T>& a)
 
 template <typename T, typename Alloc>
 OCTAVE_API
-Sparse<T, Alloc>::~Sparse (void)
+Sparse<T, Alloc>::~Sparse ()
 {
   if (--m_rep->m_count == 0)
     delete m_rep;
@@ -774,8 +772,8 @@ Sparse<T, Alloc>::range_error (const char *fcn, octave_idx_type n)
 template <typename T, typename Alloc>
 OCTAVE_API
 T
-Sparse<T, Alloc>::range_error (const char *fcn, octave_idx_type i,
-                                             octave_idx_type j) const
+Sparse<T, Alloc>::range_error (const char *fcn,
+                               octave_idx_type i, octave_idx_type j) const
 {
   (*current_liboctave_error_handler)
     ("%s (%" OCTAVE_IDX_TYPE_FORMAT ", %" OCTAVE_IDX_TYPE_FORMAT "): "
@@ -785,8 +783,8 @@ Sparse<T, Alloc>::range_error (const char *fcn, octave_idx_type i,
 template <typename T, typename Alloc>
 OCTAVE_API
 T&
-Sparse<T, Alloc>::range_error (const char *fcn, octave_idx_type i,
-                                             octave_idx_type j)
+Sparse<T, Alloc>::range_error (const char *fcn,
+                               octave_idx_type i, octave_idx_type j)
 {
   (*current_liboctave_error_handler)
     ("%s (%" OCTAVE_IDX_TYPE_FORMAT ", %" OCTAVE_IDX_TYPE_FORMAT "): "
@@ -797,7 +795,7 @@ template <typename T, typename Alloc>
 OCTAVE_API
 T
 Sparse<T, Alloc>::range_error (const char *fcn,
-                                             const Array<octave_idx_type>& ra_idx) const
+                               const Array<octave_idx_type>& ra_idx) const
 {
   std::ostringstream buf;
 
@@ -1138,9 +1136,9 @@ Sparse<T, Alloc>::insert (const Sparse<T, Alloc>& a,
 template <typename T, typename Alloc>
 OCTAVE_API
 Sparse<T, Alloc>
-Sparse<T, Alloc>::transpose (void) const
+Sparse<T, Alloc>::transpose () const
 {
-  assert (ndims () == 2);
+  liboctave_panic_unless (ndims () == 2);
 
   octave_idx_type nr = rows ();
   octave_idx_type nc = cols ();
@@ -1166,7 +1164,7 @@ Sparse<T, Alloc>::transpose (void) const
         retval.xridx (q) = j;
         retval.xdata (q) = data (k);
       }
-  assert (nnz () == retval.xcidx (nr));
+  liboctave_panic_unless (nnz () == retval.xcidx (nr));
   // retval.xcidx[1:nr] holds row entry *end* offsets for rows 0:(nr-1)
   // and retval.xcidx[0:(nr-1)] holds their row entry *start* offsets
 
@@ -1200,7 +1198,7 @@ Sparse<T, Alloc>::delete_elements (const octave::idx_vector& idx)
 {
   Sparse<T, Alloc> retval;
 
-  assert (ndims () == 2);
+  liboctave_panic_unless (ndims () == 2);
 
   octave_idx_type nr = dim1 ();
   octave_idx_type nc = dim2 ();
@@ -1301,7 +1299,7 @@ void
 Sparse<T, Alloc>::delete_elements (const octave::idx_vector& idx_i,
                                    const octave::idx_vector& idx_j)
 {
-  assert (ndims () == 2);
+  liboctave_panic_unless (ndims () == 2);
 
   octave_idx_type nr = dim1 ();
   octave_idx_type nc = dim2 ();
@@ -1436,7 +1434,7 @@ Sparse<T, Alloc>::index (const octave::idx_vector& idx, bool resize_ok) const
 {
   Sparse<T, Alloc> retval;
 
-  assert (ndims () == 2);
+  liboctave_panic_unless (ndims () == 2);
 
   octave_idx_type nr = dim1 ();
   octave_idx_type nc = dim2 ();
@@ -1639,7 +1637,7 @@ Sparse<T, Alloc>::index (const octave::idx_vector& idx_i,
 {
   Sparse<T, Alloc> retval;
 
-  assert (ndims () == 2);
+  liboctave_panic_unless (ndims () == 2);
 
   octave_idx_type nr = dim1 ();
   octave_idx_type nc = dim2 ();
@@ -1884,7 +1882,7 @@ Sparse<T, Alloc>::assign (const octave::idx_vector& idx,
 {
   Sparse<T, Alloc> retval;
 
-  assert (ndims () == 2);
+  liboctave_panic_unless (ndims () == 2);
 
   octave_idx_type nr = dim1 ();
   octave_idx_type nc = dim2 ();
@@ -1972,7 +1970,7 @@ Sparse<T, Alloc>::assign (const octave::idx_vector& idx,
           else if (idx.is_range () && idx.increment () == -1)
             {
               // It's s(u:-1:l) = r.  Reverse the assignment.
-              assign (idx.sorted (), rhs.index (octave::idx_vector (rhl - 1, 0, -1)));
+              assign (idx.sorted (), rhs.index (octave::idx_vector (rhl - 1, -1, -1)));
             }
           else if (idx.is_permutation (n))
             {
@@ -1999,10 +1997,10 @@ Sparse<T, Alloc>::assign (const octave::idx_vector& idx,
               // Disassembly our matrix...
               Array<octave_idx_type> new_ri (dim_vector (new_nz, 1));
               Array<T> new_data (dim_vector (new_nz, 1));
-              std::copy_n (tmp.ridx (), nz, new_ri.fortran_vec ());
-              std::copy_n (tmp.data (), nz, new_data.fortran_vec ());
+              std::copy_n (tmp.ridx (), nz, new_ri.rwdata ());
+              std::copy_n (tmp.data (), nz, new_data.rwdata ());
               // ... insert new data (densified) ...
-              idx.copy_data (new_ri.fortran_vec () + nz);
+              idx.copy_data (new_ri.rwdata () + nz);
               new_data.assign (octave::idx_vector (nz, new_nz), rhs.array_value ());
               // ... reassembly.
               *this = Sparse<T, Alloc> (new_data, new_ri, 0, nr, nc, false);
@@ -2031,8 +2029,7 @@ Sparse<T, Alloc>::assign (const octave::idx_vector& idx,
 template <typename T, typename Alloc>
 OCTAVE_API
 void
-Sparse<T, Alloc>::assign (const octave::idx_vector& idx,
-                                        const T& rhs)
+Sparse<T, Alloc>::assign (const octave::idx_vector& idx, const T& rhs)
 {
   // FIXME: Converting the RHS and forwarding to the sparse matrix
   // assignment function is simpler, but it might be good to have a
@@ -2050,7 +2047,7 @@ Sparse<T, Alloc>::assign (const octave::idx_vector& idx_i,
 {
   Sparse<T, Alloc> retval;
 
-  assert (ndims () == 2);
+  liboctave_panic_unless (ndims () == 2);
 
   octave_idx_type nr = dim1 ();
   octave_idx_type nc = dim2 ();
@@ -2144,7 +2141,7 @@ Sparse<T, Alloc>::assign (const octave::idx_vector& idx_i,
                   mx_inline_add (ub - lb, cidx () + lb + 1, rhs.cidx () + 1,
                                  li);
 
-                  assert (nnz () == new_nz);
+                  liboctave_panic_unless (nnz () == new_nz);
                 }
               else
                 {
@@ -2172,14 +2169,14 @@ Sparse<T, Alloc>::assign (const octave::idx_vector& idx_i,
                   mx_inline_add (nc - ub, cidx () + ub + 1,
                                  tmp.cidx () + ub + 1, new_nz - nz);
 
-                  assert (nnz () == new_nz);
+                  liboctave_panic_unless (nnz () == new_nz);
                 }
             }
           else if (idx_j.is_range () && idx_j.increment () == -1)
             {
               // It's s(:,u:-1:l) = r.  Reverse the assignment.
               assign (idx_i, idx_j.sorted (),
-                      rhs.index (idx_i, octave::idx_vector (m - 1, 0, -1)));
+                      rhs.index (idx_i, octave::idx_vector (m - 1, -1, -1)));
             }
           else if (idx_j.is_permutation (nc))
             {
@@ -2757,7 +2754,7 @@ Sparse<T, Alloc>::cat (int dim, octave_idx_type n,
         break;
       }
     default:
-      assert (false);
+      (*current_liboctave_error_handler) ("Sparse<T, Alloc>::cat: invalid dimension = %d - please report this bug", dim);
     }
 
   return retval;
