@@ -1,4 +1,9 @@
-## Copyright (C) 2010-2018 John W. Eaton
+########################################################################
+##
+## Copyright (C) 2010-2025 The Octave Project Developers
+##
+## See the file COPYRIGHT.md in the top-level directory of this
+## distribution or <https://octave.org/copyright/>.
 ##
 ## This file is part of Octave.
 ##
@@ -15,28 +20,30 @@
 ## You should have received a copy of the GNU General Public License
 ## along with Octave; see the file COPYING.  If not, see
 ## <https://www.gnu.org/licenses/>.
+##
+########################################################################
 
 ## -*- texinfo -*-
-## @deftypefn {} {} is_valid_file_id (@var{fid})
+## @deftypefn {} {@var{tf} =} is_valid_file_id (@var{fid})
 ## Return true if @var{fid} refers to an open file.
 ## @seealso{freport, fopen}
 ## @end deftypefn
 
-function retval = is_valid_file_id (fid)
+function tf = is_valid_file_id (fid)
 
-  retval = false;
-
-  if (nargin == 1)
-    try
-      if (isscalar (fid))
-        [file, mode, arch] = fopen (fid);
-        retval = ! isempty (file);
-      endif
-    end_try_catch
-  else
+  if (nargin < 1)
     print_usage ();
   endif
 
+  tf = false;
+
+  try
+    if (isscalar (fid))
+      [file, mode, arch] = fopen (fid);
+      tf = ! isempty (file);
+    endif
+  end_try_catch
+
 endfunction
 
 
@@ -45,3 +52,14 @@ endfunction
 %!assert (! is_valid_file_id ("not_a_file_id"))
 %!assert (! is_valid_file_id (-1))
 %!assert (! is_valid_file_id (pi))
+%!test <*65543>
+%! unwind_protect
+%!   fid = tmpfile ();
+%!   assert (is_valid_file_id (fid));
+%! unwind_protect_cleanup
+%!   fclose (fid);
+%! end_unwind_protect
+
+## Test input validation
+%!error <Invalid call> is_valid_file_id ()
+
